@@ -91,10 +91,12 @@ def load_configuration():
     # Qgis api endpoints
     CONFIG.add_section('api.endpoints')
     CONFIG.set('api.endpoints', 'landing_page', getenv('QGSRV_API_ENDPOINTS_LANDING_PAGE','/ows/catalog'))
+    CONFIG.set('api.endpoints', 'lizmap_api', getenv('QGSRV_API_ENDPOINTS_LIZMAP','/lizmap'))
 
     # Services enabled
     CONFIG.add_section('api.enabled')
     CONFIG.set('api.enabled', 'landing_page', getenv('QGSRV_API_ENABLED_LANDING_PAGE','no'))
+    CONFIG.set('api.enabled', 'lizmap_api', getenv('QGSRV_API_ENABLED_LIZMAP','no'))
 
     # Landing page config mapping
     # see: https://github.com/qgis/QGIS/pull/38189#issuecomment-875682735
